Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3494)

Unified Diff: base/sequence_checker_impl.h

Issue 2189113002: Rename CalledOnValidSequencedThread() to CalledOnValidSequence(). (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/sequence_checker.h ('k') | base/sequence_checker_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/sequence_checker_impl.h
diff --git a/base/sequence_checker_impl.h b/base/sequence_checker_impl.h
index 8e2c06376739d75b394c41a558455dd636fc17ff..74039718f62de96890aeee3c6e6524766523a1c0 100644
--- a/base/sequence_checker_impl.h
+++ b/base/sequence_checker_impl.h
@@ -28,10 +28,10 @@ class BASE_EXPORT SequenceCheckerImpl {
// Returns true if called in sequence with previous calls to this method and
// the constructor.
- bool CalledOnValidSequencedThread() const WARN_UNUSED_RESULT;
+ bool CalledOnValidSequence() const WARN_UNUSED_RESULT;
// Unbinds the checker from the currently associated sequence. The checker
// will be re-bound on the next call to CalledOnValidSequencedThread().
void DetachFromSequence();
private:
« no previous file with comments | « base/sequence_checker.h ('k') | base/sequence_checker_impl.cc » ('j') | no next file with comments »
@@ -28,10 +28,10 @@ class BASE_EXPORT SequenceCheckerImpl {
// Unbinds the checker from the currently associated sequence. The checker
- // will be re-bound on the next call to CalledOnValidSequencedThread().
+ // will be re-bound on the next call to CalledOnValidSequence().
void DetachFromSequence();
private:

Powered by Google App Engine
This is Rietveld 408576698